package org.diligentproject.searchservice.clients;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.Vector;

import org.apache.axis.message.addressing.Address;
import org.apache.axis.message.addressing.EndpointReferenceType;
import org.diligentproject.searchservice.mergeoperator.stubs.*;
import org.diligentproject.searchservice.mergeoperator.stubs.service.*;

public class MergeOperatorClient {
	
	static String serviceURI=null;
	static String []eprs=null;
	static Vector<String> feprs=null;
	static String outFile=null;
	
	public static void main(String[] args) {
		try{
			if(!parseInput(args)){
				System.out.println("-location <host>:<port> -eprs <[eprs]> -output <filename>");
				return;
			}
			
			EndpointReferenceType endpoint = new EndpointReferenceType();
			endpoint.setAddress(new Address(serviceEndPoint()));
			MergeOperatorServiceAddressingLocator locator= new MergeOperatorServiceAddressingLocator();
			MergeOperatorPortType pt= locator.getMergeOperatorPortTypePort(endpoint);
			Merge params=new Merge();
			params.setEprs(eprs);
			writeFile(pt.merge(params),outFile);
		}catch (Exception e){
			e.printStackTrace();
		}
	}
	
	private static boolean parseInput(String []args){
		try{
			for (int i=0;i<args.length;i+=1){
				if (args[i].equalsIgnoreCase("-location")){
					if(serviceURI!=null) return false;
					i+=1;
					serviceURI=args[i];
				}
				if (args[i].equalsIgnoreCase("-output")){
					if(outFile!=null) return false;
					i+=1;
					outFile=args[i];
				}
				if (args[i].equalsIgnoreCase("-eprs")){
					if(feprs!=null) return false;
					feprs=new Vector<String>();
					i+=1;
					while (!args[i].equalsIgnoreCase("-location") && 
							!args[i].equalsIgnoreCase("-expression") &&
							!args[i].equalsIgnoreCase("-output") &&
							!args[i].equalsIgnoreCase("-eprs") &&
							i<args.length){
								feprs.add(args[i]);
								i+=1;
					}
					eprs=new String[feprs.size()];
					for (int q=0;q<feprs.size();q+=1){
						eprs[i]=readFile(feprs.get(q));
					}					
				}
			}
			if (serviceURI==null || outFile==null||eprs==null||eprs.length==0 ) return false;
			return true;
		}catch(Exception e){
			e.printStackTrace();
			return false;
		}
	}
	
	private static String readFile(String filename) throws Exception{
		FileReader fr=new FileReader(filename);
		BufferedReader br=new BufferedReader(fr);
		StringBuilder buf=new StringBuilder();
		String line =br.readLine();
		while (line!=null){
			buf.append(line);
			line=br.readLine();
		}
		br.close();
		fr.close();
		return buf.toString();
	}
	
	private static void writeFile(String text,String filename) throws Exception{
		FileWriter fw=new FileWriter(filename);
		BufferedWriter bw=new BufferedWriter(fw);
		bw.write(text);
		bw.close();
		fw.close();
	}

	private static String serviceEndPoint(){
		return "http://"+serviceURI+"/wsrf/services/diligentproject/searchservice/SearchMasterService";
	}
}
