package org.diligentproject.searchservice.clients;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;

import org.apache.axis.message.addressing.Address;
import org.apache.axis.message.addressing.EndpointReferenceType;
import org.diligentproject.searchservice.transformbyxsltoperator.stubs.*;
import org.diligentproject.searchservice.transformbyxsltoperator.stubs.service.*;

public class TransformClient {
	
	static String serviceURI=null;
	static String expression=null;
	static String epr=null;
	static String fepr=null;
	static String outFile=null;
	
	public static void main(String[] args) {
		try{
			if(!parseInput(args)){
				System.out.println("-location <host>:<port> -expression <expression> -epr <epr> -output <filename>");
				return;
			}
			
			EndpointReferenceType endpoint = new EndpointReferenceType();
			endpoint.setAddress(new Address(serviceEndPoint()));
			
			TransformByXSLTOperatorServiceAddressingLocator locator= new TransformByXSLTOperatorServiceAddressingLocator();
			TransformByXSLTOperatorPortType pt= locator.getTransformByXSLTOperatorPortTypePort(endpoint);
			ProjectXSLT params=new ProjectXSLT();
			params.setInEPR(epr);
			params.setXslt(expression);
			writeFile(pt.projectXSLT(params),outFile);
		}catch (Exception e){
			e.printStackTrace();
		}
	}
	
	private static boolean parseInput(String []args){
		try{
			for (int i=0;i<args.length;i+=1){
				if (args[i].equalsIgnoreCase("-location")){
					if(serviceURI!=null) return false;
					i+=1;
					serviceURI=args[i];
				}
				if (args[i].equalsIgnoreCase("-expression")){
					if(expression!=null) return false;
					i+=1;
					expression=readFile(args[i]);
				}
				if (args[i].equalsIgnoreCase("-output")){
					if(outFile!=null) return false;
					i+=1;
					outFile=args[i];
				}
				if (args[i].equalsIgnoreCase("-epr")){
					if(fepr!=null) return false;
					i+=1;
					fepr=args[i];
					epr=readFile(fepr);
				}
			}
			if (serviceURI==null || expression==null|| outFile==null||epr==null) return false;
			return true;
		}catch(Exception e){
			e.printStackTrace();
			return false;
		}
	}
	
	private static String readFile(String filename) throws Exception{
		FileReader fr=new FileReader(filename);
		BufferedReader br=new BufferedReader(fr);
		StringBuilder buf=new StringBuilder();
		String line =br.readLine();
		while (line!=null){
			buf.append(line);
			line=br.readLine();
		}
		br.close();
		fr.close();
		return buf.toString();
	}
	
	private static void writeFile(String text,String filename) throws Exception{
		FileWriter fw=new FileWriter(filename);
		BufferedWriter bw=new BufferedWriter(fw);
		bw.write(text);
		bw.close();
		fw.close();
	}
	
	private static String serviceEndPoint(){
		return "http://"+serviceURI+"/wsrf/services/diligentproject/searchservice/SearchMasterService";
	}

}
